@@ -17,6 +17,11 @@
 Volume transfer interface (1.1 extension).
 """
 
+try:
+    from urllib import urlencode
+except ImportError:
+    from urllib.parse import urlencode
+import six
 from cinderclient import base
 
 
@@ -35,7 +40,7 @@ class VolumeTransferManager(base.ManagerWithFind):
     resource_class = VolumeTransfer
 
     def create(self, volume_id, name=None):
-        """Create a volume transfer.
+        """Creates a volume transfer.
 
         :param volume_id: The ID of the volume to transfer.
         :param name: The name of the transfer.
@@ -48,7 +53,7 @@ class VolumeTransferManager(base.ManagerWithFind):
     def accept(self, transfer_id, auth_key):
         """Accept a volume transfer.
 
-        :param transfer_id: The ID of the trasnfer to accept.
+        :param transfer_id: The ID of the transfer to accept.
         :param auth_key: The auth_key of the transfer.
         :rtype: :class:`VolumeTransfer`
         """
@@ -69,10 +74,23 @@ class VolumeTransferManager(base.ManagerWithFind):
 
         :rtype: list of :class:`VolumeTransfer`
         """
-        if detailed is True:
-            return self._list("/os-volume-transfer/detail", "transfers")
-        else:
-            return self._list("/os-volume-transfer", "transfers")
+        if search_opts is None:
+            search_opts = {}
+
+        qparams = {}
+
+        for opt, val in six.iteritems(search_opts):
+            if val:
+                qparams[opt] = val
+
+        query_string = "?%s" % urlencode(qparams) if qparams else ""
+
+        detail = ""
+        if detailed:
+            detail = "/detail"
+
+        return self._list("/os-volume-transfer%s%s" % (detail, query_string),
+                          "transfers")
 
     def delete(self, transfer_id):
         """Delete a volume transfer.
